@@ -1,8 +1,10 @@
 use std::net::SocketAddr;
 
-#[cfg(feature = "test-isahc")]
-use isahc::HttpClient as IsahcHttpClient;
+#[cfg(feature = "record-isahc")]
+use isahc::HttpClient as IsahcClient;
 use log::{error, info};
+#[cfg(feature = "record-reqwest")]
+use reqwest::Client as ReqwestClient;
 use tokio::sync::mpsc::Sender;
 
 use config::RecordConfig;
@@ -11,8 +13,10 @@ use logger::RecordLogger;
 use proxy::Proxy;
 use writer::StubWriter;
 
-#[cfg(feature = "test-isahc")]
+#[cfg(feature = "record-isahc")]
 use crate::isahc_client;
+#[cfg(feature = "record-reqwest")]
+use crate::reqwest_client;
 
 use super::model::JsonStub;
 
@@ -21,7 +25,7 @@ mod proxy;
 mod mapping;
 pub mod config;
 mod warp_exchange;
-pub mod test;
+pub mod client;
 mod port;
 mod writer;
 mod logger;
@@ -55,10 +59,15 @@ impl StubrRecord {
         Self { addr, tx }
     }
 
-    #[cfg(feature = "test-isahc")]
-    pub fn isahc_client(&self) -> IsahcHttpClient {
+    #[cfg(feature = "record-isahc")]
+    pub fn isahc_client(&self) -> IsahcClient {
         isahc_client(self.uri())
     }
+
+    #[cfg(feature = "record-reqwest")]
+    pub fn reqwest_client(&self) -> ReqwestClient {
+        reqwest_client(self.uri())
+    }
 }
 
 impl Drop for StubrRecord {
